@@ -772,7 +772,7 @@ class JointExonModel:
             df.to_csv(outfp, sep="\t", index=True)
         return df
 
-    def load_regression_table(self, outfp):
+    def load_regression_table(self, outfp, fast_load=False):
         """Load a pre-computed regression results into the current instance
 
         For each covariate, the coefficients and variance estimates for coefficients are reloaded to the precision of 1e-5. Then, the 
@@ -781,6 +781,9 @@ class JointExonModel:
         Parameters
         ----------
         outfp : str
+        fast_load : bool
+            If true, skip re-computation of p-values and stats test, and use these values from the file as-is; may lose some precision.
+            Default is False.
 
         Returns
         -------
@@ -798,20 +801,25 @@ class JointExonModel:
             cov_names = [str(x) for x in row['covariate_names'].split(',')]
             beta_mle = np.array([float(x) for x in row['covariate_est'].split(',')])
             mle_var = np.array([float(x) for x in row['covariate_var'].split(',')])
-            chi2_stats = beta_mle ** 2 / mle_var
-            pvals = 1 - scipy.stats.chi2.cdf(chi2_stats, df=1)
-            wald_test = {'coef': beta_mle, 'var': mle_var, 'chi2.wald': chi2_stats, 'pvals': pvals}
-            wald_test = pd.DataFrame(wald_test, index=cov_names)
-            if self.diff_intercept_by_measure:
-                assert sorted(cov_names) == sorted(self.covariates.columns.tolist() + [
-                    '_junc_diff_']), 'reloaded regressiton table does not match covariates in this instance; aborting. check your file: %s, %s, %s' % (
-                    outfp, sorted(cov_names), sorted(self.covariates.columns.tolist() + ['_junc_diff_']))
+            if fast_load:
+                qvals = np.array([float(x) for x in row['covariate_qval'].split(',')])
+                wald_test = {'coef': beta_mle, 'var': mle_var, 'qvals': qvals}
+                wald_test = pd.DataFrame(wald_test, index=cov_names)
             else:
-                assert sorted(cov_names) == sorted(
-                    self.covariates.columns.tolist()), 'reloaded regressiton table does not match covariates in this instance; aborting'
-
+                chi2_stats = beta_mle ** 2 / mle_var
+                pvals = 1 - scipy.stats.chi2.cdf(chi2_stats, df=1)
+                wald_test = {'coef': beta_mle, 'var': mle_var, 'chi2.wald': chi2_stats, 'pvals': pvals}
+                wald_test = pd.DataFrame(wald_test, index=cov_names)
+                if self.diff_intercept_by_measure:
+                    assert sorted(cov_names) == sorted(self.covariates.columns.tolist() + [
+                        '_junc_diff_']), 'reloaded regressiton table does not match covariates in this instance; aborting. check your file: %s, %s, %s' % (
+                        outfp, sorted(cov_names), sorted(self.covariates.columns.tolist() + ['_junc_diff_']))
+                else:
+                    assert sorted(cov_names) == sorted(
+                        self.covariates.columns.tolist()), 'reloaded regressiton table does not match covariates in this instance; aborting'
             self.stats_tests[eid] = wald_test
-        _ = self.multiple_testing_correction()
+        if fast_load is False:
+            _ = self.multiple_testing_correction()
         return self
 
     def get_das_cnt(self, target_covariate, qval_thresh=0.05):
@@ -1028,8 +1036,8 @@ class JemmLinearMixedModel(JemmLinearRegression):
                 (reg_table['coef'].abs() > self._MAX_ABS_COEF) & (
                         reg_table.index != self._group_varname), 'pvals'] = 1.
 
-    def load_regression_table(self, outfp):
-        super(JemmLinearMixedModel, self).load_regression_table(outfp=outfp)
+    def load_regression_table(self, outfp, fast_load=False):
+        super(JemmLinearMixedModel, self).load_regression_table(outfp=outfp, fast_load=fast_load)
         outdf = pd.read_table(outfp)
         for i in range(outdf.shape[0]):
             row = outdf.iloc[i]
